Crate namada_test_utils

Crate namada_test_utils 

Utilities for use in tests.

Modules

ibc
Helper functions for testing IBC client upgrade
tx_data
Types that are meant to be serialized and used as the data component of a Namada transaction.

Structs

TestWasmsIter
An iterator over the variants of TestWasms

Enums

TestWasms
Corresponds to wasms that we build for tests, under WASM_FOR_TESTS_DIR. See the wasm_for_tests/wasm_source crate for documentation on what these wasms do.

Constants

WASM_FOR_TESTS_DIR
Path from the root of the Git repo to the directory under which built test wasms can be found.