Utilities for use in tests.
Modules
- ibc
- Helper functions for testing IBC client upgrade
- tx_data
- Types that are meant to be serialized and used as the data component of a Namada transaction.
Structs
- Test
Wasms Iter - An iterator over the variants of TestWasms
Enums
- Test
Wasms - Corresponds to wasms that we build for tests, under
WASM_FOR_TESTS_DIR. See thewasm_for_tests/wasm_sourcecrate for documentation on what these wasms do.
Constants
- WASM_
FOR_ TESTS_ DIR - Path from the root of the Git repo to the directory under which built test wasms can be found.