Types that are meant to be serialized and used as the data component of a Namada transaction.
Structs
- TxMint
Data - Represents minting of the specified token. This should
be used alongside the test
tx_mint_tokens.wasm. - TxWrite
Data - Represents an arbitrary write to storage at the specified key. This should
be used alongside the test
tx_write.wasm.